@@ -22,12 +22,12 @@
 
 Hexagons<-function (Coords,Row,Col,color = NA, border = "gray",unitcell=1)
 {  Apo<-unitcell/2;R<-Apo/(cos(pi/6));
-   opar <- par(mar=c(1,1,1,2),pty="m",xpd=TRUE,family="serif");
    plot(c(1-2*Apo,Col+Apo),c(1-R,1+(Row-1)*(R*1.5)+R),
    type="n",xlab="",ylab="",xaxs="i",yaxs="i",xaxt="n",yaxt="n",bty="n");
    for (i in c(1:nrow(Coords))) {Hexa(Coords$X[i],Coords$Y[i],color=color,border=border)}
-   on.exit(par(opar))
 }
 
 
 
+
+
